// enc3to8wraper.v

module enc3to8wraper(
  PCLK,
  PENABLE,
  PSEL,
  PRESERN,
  PWRITE,
  PREADY,
  PSLVERR,
  PADDR,
  PWDATA,
  PRDATA,
  LED,
  SW);


input PCLK,PENABLE, PSEL, PRESERN, PWRITE;
input  [31:0] PWDATA;
input  [3:0] PADDR;
input  [1:0] SW;
output [31:0] PRDATA;
output [7:0] LED;
output PREADY, PSLVERR;

wire rd_enable;
wire wr_enable;

reg  [31:0]   led_reg;
reg  [31:0]   sw_reg;
reg  [31:0]   PRDATA;

assign wr_enable = (PENABLE &&  PWRITE && PSEL);
assign rd_enable = (!PWRITE && PSEL); //Data is ready during first cycle to make it availble on the bus when PENABLE is asserted

enc3to8 enc3to8_0 (.data(led_reg[2:0]), .y(LED [7:0]));

assign PREADY = 1'b1; 
assign PSLVERR = 1'b0;         

always@(posedge PCLK or negedge PRESERN)
  if(~PRESERN)
    begin
      led_reg <= 32'hffffffff;
      sw_reg[31:2] <= 30'h00000000;
    end
  else
    begin 
	  case(PADDR[3:2])
      2'b00:
        begin
          if(wr_enable)
          begin
            led_reg <= PWDATA;
          end
        end
      2'b01:
        begin
          if(rd_enable)
            begin
              PRDATA[31:0] <= sw_reg[31:0];
            end
        end
      default:
        begin
            if(rd_enable)
              begin
                PRDATA <= led_reg;
              end
        end
      endcase
    end

always@*
  if(~PRESERN)
    begin
      sw_reg[1:0] <= 2'b00;
    end
  else
    begin
        sw_reg[1:0] <= SW;
    end
  
endmodule